@@ -1,4 +1,4 @@
-from sql import SQLite, SQL
+from YamlBase.sql import SQLite, SQL
 
 
 class DBWorker:
